@@ -21,5 +21,8 @@ class ServerCommand(SyncCommand):
             'access_log': application.config.APPLICATION_DEBUG,
 
             'workers': application.config.APPLICATION_WORKERS,
+
+            # @TODO: Remove builtin MOTD and replace with insanic implementation
+            'motd': True,
         }
         application.run(**server_config)
