@@ -1,11 +1,12 @@
 from http import HTTPStatus as HTTP_STATUS
 from typing import Any
 
-from sanic.request import Request as SanicRequest
+from sanic.request import Request as SanicRequest, File
 from sanic.response import BaseHTTPResponse, HTTPResponse
 
 __all__ = (
     'HTTP_STATUS',
+    'File',
     'Request',
     'Response',
 )
